@@ -6,12 +6,17 @@ This file mustr be kept at the same level as the plugin "pyp" file so we can ext
 """
 import os
 import re
+import c4d
 
 LABEL_WIDTH = 180
 LABEL_HEIGHT = 14
 INT_FIELD_WIDTH = 100
 PLUGIN_ID = 1055243 # registered for Conductor at Maxon
 
+
+C4D_VERSION = int(c4d.GetC4DVersion() / 1000)
+ 
+
 PLUGIN_DIR = os.path.dirname(__file__)
 VERSION = u"dev.999"
 try:
